/*
 * Raima Database Manager
 *
 * Copyright (C) 2019 Raims Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 */
#include <stdio.h>
#include "perftimer.h"

#if defined(WIN32)
 /* Windows */
#include <sys/types.h>
#include <sys/timeb.h>
#else
 /* Linux */
#include <sys/time.h>
#endif

static unsigned int timeMeasureMilliSecs()
{
#if defined(WIN32)
    /* Windows */
    struct _timeb tb;

    _ftime_s(&tb);

    return ((unsigned int)tb.time) * 1000 + (unsigned int)tb.millitm;
#else
    /* Linux */
    struct timeval tv;

    gettimeofday(&tv, NULL);
    return (unsigned int)tv.tv_sec * 1000 + (unsigned int)tv.tv_usec / 1000;
#endif
}

void timeMeasureBegin(
    perfTimer_t *timer)
{
    timer->start = timeMeasureMilliSecs();
}

void timeMeasureEnd(
    perfTimer_t *timer)
{
    timer->end = timeMeasureMilliSecs();
}

unsigned int timeMeasureDiff(
    perfTimer_t *timer)
{
    return timer->end - timer->start;
}
