/* ----------------------------------------------------------------------------
 * Raima Database Manager
 *
 * Copyright (c) 2014 Raima Inc.,  All rights reserved.
 *
 * Use of this software, whether in source code format, or in executable,
 * binary object code form, is governed by the Raima LICENSE which
 * is fully described in the LICENSE.TXT file, included within this
 * distribution of files.
 * ----------------------------------------------------------------------------
 */

/** \file rdmretcodeapi.h
 *  \brief Header for the RDM Error APIs
 */

#include "psptypes.h"
#include "rdmretcodetypes.h"

/**
 *
 * \defgroup error RDM Return Code APIs
 *
 * The RDM return code API.  The functions here are located in \lib{rdm}
 *
 * \ingroup rdm
 * \addtogroup error
 * @{*/

#if defined(RDM_UNICODE)
#define rdm_retcodeGetCode RDM_T_FUNC (rdm_retcodeGetCode)
#define rdm_retcodeGetDescription RDM_T_FUNC (rdm_retcodeGetDescription)
#define rdm_retcodeGetName RDM_T_FUNC (rdm_retcodeGetName)
#endif

#if defined(__cplusplus)
extern "C" {
#endif

/** \brief Get the numeric RDM status code for a literal status name

    This function returns the RDM status code associated with the specified
    mnemonic status name.

    \par Locking Requirements
    None

    \returns
        - An RDM_RETCODE value that corresponds to the mnemonic status name
        - eSYS_BADERRCODE if an invalid mnemonic status name is given

    \see rdm_retcodeGetName
*/
RDM_EXPORT RDM_RETCODE EXTERNAL_FCN
rdm_retcodeGetCode (const RDM_TCHAR_T *retCodeName);

/** \brief Invoke RDM error handler
    \returns
        - The status/error code description string
        - NULL if an invalid RDM_RETCODE value is given

    \see rdm_retcodeGetName
*/
RDM_EXPORT const RDM_TCHAR_T *EXTERNAL_FCN rdm_retcodeGetDescription (
    RDM_RETCODE retcode /**< [in] Status or error code returned by an RDM API function */
);

/** \brief Get the mnemonic name for an error or status code

    This function returns the mnemonic name associated with the specified error
    or status code.

    \par Locking Requirements
    None

    \returns
        - The status/error code mnemonic name string
        - NULL if an invalid RDM_RETCODE value is given

    \see rdm_retcodeGetDescription
*/
RDM_EXPORT const RDM_TCHAR_T *EXTERNAL_FCN rdm_retcodeGetName (
    RDM_RETCODE retcode /**< [in] Status or error code returned by an RDM API function */
);

#if defined(__cplusplus)
}
#endif

/** @}*/
